Image creation library for gguppy
arwggplot
[!CAUTION] 🚧 This package is still in work and subject to great change.
arwggplot is part of the gguppy plotting library, but can also be used on its own to create images.
- 🛠️ Minimalist svg backend for
gguppyinno_stdRust - 🛠️ Features vector backends to svg, eps, and more
- 🛠️ Features raster backends to bmp, png, and more
Module Structure
- src
-
lib.rs -
modandre-export -
svg - non-exhaustive implementation of the svg specification in
no_stdRustHeavily inspired by https://github.com/bodoni/svg and https://github.com/RazrFalcon/resvg/tree/master/crates/usvg but not a drop-in replacement for either of them
- mod.rs -
modandre-export - attribute.rs - SVG attributes
- element.rs - SVG elements
- mod.rs -
-