pub struct Polyline {
pub points: &'static str,
pub fill: Option<&'static str>,
pub stroke: Option<&'static str>,
pub stroke_width: Option<f32>,
pub opacity: Option<f32>,
pub id: Option<&'static str>,
pub class: Option<&'static str>,
}Expand description
Polyline SVG element (<polyline>).
See also: https://developer.mozilla.org/en-US/docs/Web/SVG/Element/polyline
Draws straight lines connecting several points. Typically a polyline is used to create open shapes as the last point doesn’t have to be connected to the first point. For closed shapes see the <polygon> element.
SVG Tutorial: SVG Basic Shape.
Fields
points: &'static strfill: Option<&'static str>stroke: Option<&'static str>stroke_width: Option<f32>opacity: Option<f32>id: Option<&'static str>class: Option<&'static str>Implementations
Sourceimpl Polyline
impl Polyline
pub fn new(points: &'static str) -> Self
pub fn points(self, value: &'static str) -> Self
pub fn fill(self, value: &'static str) -> Self
pub fn stroke(self, value: &'static str) -> Self
pub fn stroke_width(self, value: f32) -> Self
pub fn opacity(self, value: f32) -> Self
pub fn id(self, value: &'static str) -> Self
pub fn class(self, value: &'static str) -> Self